@@ -35,12 +35,24 @@ class Node:
         self_dict = self.to_dict()
         return json.dumps(self_dict, indent=4, ensure_ascii=False)
 
+    def write_pos(self):
+        """
+        Write some semantic sentences
+        """
+        return self.template.pos.format(self.concept_name)
+    
+    def write_neg(self):
+        """
+        Write some semantic sentences
+        """
+        return self.template.neg.format(self.concept_name)
+
     def write(self):
         """
         Write some semantic sentences with labels
         """
         label_decision = 1 if self.labeled else 0
         return [
-            (self.template.pos.format(self.concept_name), label_decision),
-            (self.template.neg.format(self.concept_name), 1-label_decision)
+            (self.write_pos(), label_decision),
+            (self.write_neg(), 1-label_decision)
         ]
\ No newline at end of file
